@@ -54,15 +54,17 @@ tests=[
 	'test_filter_date_range',
 	'test_model_casting',
 	'test_model_casting_validation',
-	'test_model_copy']
+	'test_model_copy',
+	'test_one_to_one',
+	'test_prop_metadata',
+	'test_rel_metadata']
 should_fail=[
 	'test_dates',
 	'test_filter_iexact',
-	'test_one_to_one',
 	'test_relationship_model',
 	'test_datetime_auto_now_add',
 	'test_nodemodel_independence',
 	'test_str_array_property_validator',
 	'test_url_array_property_validator',
 	'test_type_query',
-	'test_model_casting_validation']
+	'test_model_casting_validation',]
